# clld-phylogeny-plugin

Plugin for the [clld](https://github.com/clld/clld) framework providing
support for phylogenetic trees in clld apps.

This plugin includes the [phylotree](https://github.com/veg/phylotree.js/tree/master)
library to render phylogenetic trees in the browser.

[![Build Status](https://travis-ci.org/clld/clld-phylogeny-plugin.svg?branch=master)](https://travis-ci.org/clld/clld-phylogeny-plugin)
[![codecov](https://codecov.io/gh/clld/clld-phylogeny-plugin/branch/master/graph/badge.svg)](https://codecov.io/gh/clld/clld-phylogeny-plugin)
[![PyPI](https://img.shields.io/pypi/v/clld-phylogeny-plugin.svg)](https://pypi.python.org/pypi/clld-phylogeny-plugin)


